@@ -22,7 +22,7 @@ class TypeClass(ABC):
         super().__init__()
     
     def _primitive_types(self, var: Any) -> bool:
-        if (type(var) == str) or (type(var) == int) or (type(var) == float) or (type(var) == bool) or (type(var) is None):
+        if (type(var) == str) or (type(var) == int) or (type(var) == float) or (type(var) == bool) or (var is None):
             return True
         else:
             return False
@@ -30,7 +30,7 @@ class TypeClass(ABC):
     def _map_types(self, key: Any) -> str:
         if type(key) == str:
             return "string"
-        elif type(key) is None:
+        elif key is None:
             return "string"
         elif type(key) == int:
             return "integer"
@@ -555,21 +555,21 @@ if __name__ =="__main__":
         "item1": "value1",
         "item2": 2,
         "item3": 3.0,
-        "item4": ["a", "list", "string", "things"]
+        "item4": None
     }
     print('\n')
     S1 = Schema(response=r1_1, example=mixed_object_body)
-    
+    S1.to_open_api_3()
     C1 = Component()
     C1.set_schemas([S1])
 
 
 
-    OADB = OpenApiDocBuilder(file_location=None)
-    current_yaml = OADB.read_current_file()
-    current_yaml["paths"] = E1.to_open_api_3()
-    current_yaml.update(C1.to_open_api_3())
-    OADB.write_to_file(current_yaml)
+    # OADB = OpenApiDocBuilder(file_location=None)
+    # current_yaml = OADB.read_current_file()
+    # current_yaml["paths"] = E1.to_open_api_3()
+    # current_yaml.update(C1.to_open_api_3())
+    # OADB.write_to_file(current_yaml)
 
     
     
\ No newline at end of file
